@@ -158,6 +158,7 @@ class ProxyManager:
                         while not result_future.done():
                             await asyncio.sleep(0.1)
                             if end_event.is_set():
+                                result_future.cancel()
                                 return None
 
                         result = await result_future
@@ -206,35 +207,14 @@ class ProxyManager:
                 exception_handle(None, ex)
 
     async def start(self):
+        self._loop.set_exception_handler(lambda loop, context: None)
         await self._pool.start()
 
-        # def fn(index: int):
-        #     while self._executor_running:
-        #         try:
-        #             task = self._executor_queue.get(False)
-        #             task()
-
-        #             self._executor_queue.task_done()
-        #             continue
-        #         except Empty:
-        #             time.sleep(3)
-        #             continue
-
-        #     if self._verbose:
-        #         print("Worker {} is stopped working".format(index))
-
-        # self._executor_running = True
-        # for i in range(self._executor_workers):
-        #     self._executor.submit(fn, i)
-
     async def stop(self, forced_shutdown=False):
-        # if not forced_shutdown:
-        #     self._executor_queue.join()
-
-        # self._executor_running = False
         self._executor.shutdown(wait=True, cancel_futures=True)
 
         await self._pool.end()
+        self._loop.set_exception_handler(None)
 
     def __enter__(self):
         loop = asyncio.get_event_loop()
